FlutterMulticastLockPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterMulticastLockPlatform
Implementers

Constructors

FlutterMulticastLockPlatform()
Constructs a FlutterMulticastLockPlatform.

Properties

exceptionOnUnsupportedPlatform → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquireMulticastLock({String? lockName}) → Future<void>
isMulticastLockHeld() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseMulticastLock() → Future<void>
setExceptionOnUnsupportedPlatform(bool value) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FlutterMulticastLockPlatform
The default instance of FlutterMulticastLockPlatform to use.
getter/setter pair